import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/all_devices/models/devices_model.dart';
import 'package:syncrow_web/pages/device_managment/wall_sensor/bloc/bloc.dart';
import 'package:syncrow_web/pages/device_managment/wall_sensor/bloc/event.dart';
import 'package:syncrow_web/pages/device_managment/wall_sensor/bloc/state.dart';
import 'package:syncrow_web/pages/device_managment/shared/sensors_widgets/presence_display_data.dart';
import 'package:syncrow_web/pages/device_managment/shared/sensors_widgets/presence_static_widget.dart';
import 'package:syncrow_web/pages/device_managment/shared/sensors_widgets/presence_status.dart';
import 'package:syncrow_web/pages/device_managment/shared/sensors_widgets/presence_update_data.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';

class WallSensorControls extends StatelessWidget with HelperResponsiveLayout {
  const WallSensorControls({super.key, required this.device});

  final AllDevicesModel device;

  @override
  Widget build(BuildContext context) {
    final isLarge = isLargeScreenSize(context);
    final isMedium = isMediumScreenSize(context);
    return BlocProvider(
      create: (context) => WallSensorBloc(deviceId: device.uuid!)..add(WallSensorInitialEvent()),
      child: BlocBuilder<WallSensorBloc, WallSensorState>(
        builder: (context, state) {
          if (state is WallSensorLoadingInitialState) {
            return const Center(child: CircularProgressIndicator());
          } else if (state is WallSensorUpdateState) {
            return GridView(
              padding: const EdgeInsets.symmetric(horizontal: 50),
              shrinkWrap: true,
              physics: const NeverScrollableScrollPhysics(),
              gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                crossAxisCount: isLarge
                    ? 3
                    : isMedium
                        ? 2
                        : 1,
                mainAxisExtent: 133,
                crossAxisSpacing: 12,
                mainAxisSpacing: 12,
              ),
              children: [
                PresenceState(
                  value: state.wallSensorModel.presenceState,
                ),
                PresenceDisplayValue(
                  value: state.wallSensorModel.presenceTime.toString(),
                  postfix: 'min',
                  description: 'Presence Time',
                ),
                PresenceDisplayValue(
                  value: state.wallSensorModel.currentDistance.toString(),
                  postfix: 'cm',
                  description: 'Current Distance',
                ),
                PresenceDisplayValue(
                  value: state.wallSensorModel.illuminance.toString(),
                  postfix: 'Lux',
                  description: 'Illuminance Value',
                ),
                PresenceUpdateData(
                  value: state.wallSensorModel.motionSensitivity.toDouble(),
                  title: 'Motion Detection Sensitivity:',
                  minValue: 1,
                  maxValue: 5,
                  steps: 1,
                  action: (int value) {
                    context.read<WallSensorBloc>().add(
                          WallSensorChangeValueEvent(
                            code: 'motion_sensitivity_value',
                            value: value,
                          ),
                        );
                  },
                ),
                PresenceUpdateData(
                  value: state.wallSensorModel.motionlessSensitivity.toDouble(),
                  title: 'Motionless Detection Sensitivity:',
                  minValue: 1,
                  maxValue: 5,
                  steps: 1,
                  action: (int value) => context.read<WallSensorBloc>().add(
                        WallSensorChangeValueEvent(
                          code: 'motionless_sensitivity',
                          value: value,
                        ),
                      ),
                ),
                PresenceUpdateData(
                    value: state.wallSensorModel.noBodyTime.toDouble(),
                    title: 'Nobody Time:',
                    minValue: 10,
                    maxValue: 10000,
                    steps: 1,
                    description: 'hr',
                    action: (int value) =>
                        context.read<WallSensorBloc>().add(WallSensorChangeValueEvent(
                              code: 'no_one_time',
                              value: value,
                            ))),
                PresenceUpdateData(
                  value: state.wallSensorModel.farDetection.toDouble(),
                  title: 'Far Detection:',
                  minValue: 75,
                  maxValue: 600,
                  steps: 75,
                  description: 'cm',
                  action: (int value) => context.read<WallSensorBloc>().add(
                        WallSensorChangeValueEvent(
                          code: 'far_detection',
                          value: value,
                        ),
                      ),
                ),
                GestureDetector(
                  onTap: () {},
                  child: const PresenceStaticWidget(
                    icon: Assets.illuminanceRecordIcon,
                    description: 'Illuminance Record',
                  ),
                ),
                GestureDetector(
                  onTap: () {},
                  child: const PresenceStaticWidget(
                    icon: Assets.presenceRecordIcon,
                    description: 'Presence Record',
                  ),
                ),
              ],
            );
          } else {
            return const Center(child: Text('Error fetching status'));
          }
        },
      ),
    );
  }
}
